/** @license
 *
 * jsPDF - PDF Document creation from JavaScript
 * Version 4.2.1 Built on 2026-03-17T11:11:27.058Z
 *                      CommitID 00000000
 *
 * Copyright (c) 2010-2025 James Hall <james@parall.ax>, https://github.com/MrRio/jsPDF
 *               2015-2025 yWorks GmbH, http://www.yworks.com
 *               2015-2025 Lukas Holländer <lukas.hollaender@yworks.com>, https://github.com/HackbrettXXX
 *               2016-2018 Aras Abbasi <aras.abbasi@gmail.com>
 *               2010 Aaron Spike, https://github.com/acspike
 *               2012 Willow Systems Corporation, https://github.com/willowsystems
 *               2012 Pablo Hess, https://github.com/pablohess
 *               2012 Florian Jenett, https://github.com/fjenett
 *               2013 Warren Weckesser, https://github.com/warrenweckesser
 *               2013 Youssef Beddad, https://github.com/lifof
 *               2013 Lee Driscoll, https://github.com/lsdriscoll
 *               2013 Stefan Slonevskiy, https://github.com/stefslon
 *               2013 Jeremy Morel, https://github.com/jmorel
 *               2013 Christoph Hartmann, https://github.com/chris-rock
 *               2014 Juan Pablo Gaviria, https://github.com/juanpgaviria
 *               2014 James Makes, https://github.com/dollaruw
 *               2014 Diego Casorran, https://github.com/diegocr
 *               2014 Steven Spungin, https://github.com/Flamenco
 *               2014 Kenneth Glassey, https://github.com/Gavvers
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Contributor(s):
 *    siefkenj, ahwolf, rickygu, Midnith, saintclair, eaparango,
 *    kim3er, mfo, alnorth, Flamenco
 */

/**
 * Copyright (c) 2014-2023 Denis Pushkarev
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

var t;t=function(){var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(t,r){return t(r={exports:{}},r.exports),r.exports}var e,n,o=function(t){return t&&t.Math===Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||t||Function("return this")(),a=function(t){try{return!!t()}catch(r){return!0}},u=!a(function(){return 7!==Object.defineProperty({},1,{get:function(){return 7}})[1]}),c=!a(function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")}),f=Function.prototype.call,s=c?f.bind(f):function(){return f.apply(f,arguments)},p={}.propertyIsEnumerable,l=Object.getOwnPropertyDescriptor,y={f:l&&!p.call({1:2},1)?function(t){var r=l(this,t);return!!r&&r.enumerable}:p},h=function(t,r){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:r}},d=Function.prototype,v=d.call,g=c&&d.bind.bind(v,v),b=c?g:function(t){return function(){return v.apply(t,arguments)}},w=b({}.toString),m=b("".slice),A=function(t){return m(w(t),8,-1)},T=Object,O=b("".split),E=a(function(){return!T("z").propertyIsEnumerable(0)})?function(t){return"String"===A(t)?O(t,""):T(t)}:T,S=function(t){return null==t},j=TypeError,R=function(t){if(S(t))throw new j("Can't call method on "+t);return t},x=function(t){return E(R(t))},I="object"==typeof document&&document.all,M={all:I,IS_HTMLDDA:void 0===I&&void 0!==I},P=M.all,L=M.IS_HTMLDDA?function(t){return"function"==typeof t||t===P}:function(t){return"function"==typeof t},C=M.all,F=M.IS_HTMLDDA?function(t){return"object"==typeof t?null!==t:L(t)||t===C}:function(t){return"object"==typeof t?null!==t:L(t)},U=function(t,r){return arguments.length<2?(e=i[t],L(e)?e:void 0):i[t]&&i[t][r];var e},_=b({}.isPrototypeOf),B="undefined"!=typeof navigator&&String(navigator.userAgent)||"",D=i.process,k=i.Deno,N=D&&D.versions||k&&k.version,W=N&&N.v8;W&&(n=(e=W.split("."))[0]>0&&e[0]<4?1:+(e[0]+e[1])),!n&&B&&(!(e=B.match(/Edge\/(\d+)/))||e[1]>=74)&&(e=B.match(/Chrome\/(\d+)/))&&(n=+e[1]);var V=n,G=i.String,Y=!!Object.getOwnPropertySymbols&&!a(function(){var t=Symbol("symbol detection");return!G(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&V&&V<41}),z=Y&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,H=Object,q=z?function(t){return"symbol"==typeof t}:function(t){var r=U("Symbol");return L(r)&&_(r.prototype,H(t))},X=String,K=function(t){try{return X(t)}catch(r){return"Object"}},J=TypeError,$=function(t){if(L(t))return t;throw new J(K(t)+" is not a function")},Q=function(t,r){var e=t[r];return S(e)?void 0:$(e)},Z=TypeError,tt=Object.defineProperty,rt=function(t,r){try{tt(i,t,{value:r,configurable:!0,writable:!0})}catch(e){i[t]=r}return r},et="__core-js_shared__",nt=i[et]||rt(et,{}),ot=r(function(t){(t.exports=function(t,r){return nt[t]||(nt[t]=void 0!==r?r:{})})("versions",[]).push({version:"3.33.0",mode:"global",copyright:"© 2014-2023 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.33.0/LICENSE",source:"https://github.com/zloirock/core-js"})}),it=Object,at=function(t){return it(R(t))},ut=b({}.hasOwnProperty),ct=Object.hasOwn||function(t,r){return ut(at(t),r)},ft=0,st=Math.random(),pt=b(1..toString),lt=function(t){return"Symbol("+(void 0===t?"":t)+")_"+pt(++ft+st,36)},yt=i.Symbol,ht=ot("wks"),dt=z?yt.for||yt:yt&&yt.withoutSetter||lt,vt=function(t){return ct(ht,t)||(ht[t]=Y&&ct(yt,t)?yt[t]:dt("Symbol."+t)),ht[t]},gt=TypeError,bt=vt("toPrimitive"),wt=function(t,r){if(!F(t)||q(t))return t;var e,n=Q(t,bt);if(n){if(void 0===r&&(r="default"),e=s(n,t,r),!F(e)||q(e))return e;throw new gt("Can't convert object to primitive value")}return void 0===r&&(r="number"),function(t,r){var e,n;if("string"===r&&L(e=t.toString)&&!F(n=s(e,t)))return n;if(L(e=t.valueOf)&&!F(n=s(e,t)))return n;if("string"!==r&&L(e=t.toString)&&!F(n=s(e,t)))return n;throw new Z("Can't convert object to primitive value")}(t,r)},mt=function(t){var r=wt(t,"string");return q(r)?r:r+""},At=i.document,Tt=F(At)&&F(At.createElement),Ot=function(t){return Tt?At.createElement(t):{}},Et=!u&&!a(function(){return 7!==Object.defineProperty(Ot("div"),"a",{get:function(){return 7}}).a}),St=Object.getOwnPropertyDescriptor,jt={f:u?St:function(t,r){if(t=x(t),r=mt(r),Et)try{return St(t,r)}catch(e){}if(ct(t,r))return h(!s(y.f,t,r),t[r])}},Rt=u&&a(function(){return 42!==Object.defineProperty(function(){},"prototype",{value:42,writable:!1}).prototype}),xt=String,It=TypeError,Mt=function(t){if(F(t))return t;throw new It(xt(t)+" is not an object")},Pt=TypeError,Lt=Object.defineProperty,Ct=Object.getOwnPropertyDescriptor,Ft="enumerable",Ut="configurable",_t="writable",Bt={f:u?Rt?function(t,r,e){if(Mt(t),r=mt(r),Mt(e),"function"==typeof t&&"prototype"===r&&"value"in e&&_t in e&&!e[_t]){var n=Ct(t,r);n&&n[_t]&&(t[r]=e.value,e={configurable:Ut in e?e[Ut]:n[Ut],enumerable:Ft in e?e[Ft]:n[Ft],writable:!1})}return Lt(t,r,e)}:Lt:function(t,r,e){if(Mt(t),r=mt(r),Mt(e),Et)try{return Lt(t,r,e)}catch(n){}if("get"in e||"set"in e)throw new Pt("Accessors not supported");return"value"in e&&(t[r]=e.value),t}},Dt=u?function(t,r,e){return Bt.f(t,r,h(1,e))}:function(t,r,e){return t[r]=e,t},kt=Function.prototype,Nt=u&&Object.getOwnPropertyDescriptor,Wt=ct(kt,"name"),Vt={EXISTS:Wt,PROPER:Wt&&"something"===function(){}.name,CONFIGURABLE:Wt&&(!u||u&&Nt(kt,"name").configurable)},Gt=b(Function.toString);L(nt.inspectSource)||(nt.inspectSource=function(t){return Gt(t)});var Yt,zt,Ht,qt=nt.inspectSource,Xt=i.WeakMap,Kt=L(Xt)&&/native code/.test(String(Xt)),Jt=ot("keys"),$t=function(t){return Jt[t]||(Jt[t]=lt(t))},Qt={},Zt="Object already initialized",tr=i.TypeError,rr=i.WeakMap;if(Kt||nt.state){var er=nt.state||(nt.state=new rr);er.get=er.get,er.has=er.has,er.set=er.set,Yt=function(t,r){if(er.has(t))throw new tr(Zt);return r.facade=t,er.set(t,r),r},zt=function(t){return er.get(t)||{}},Ht=function(t){return er.has(t)}}else{var nr=$t("state");Qt[nr]=!0,Yt=function(t,r){if(ct(t,nr))throw new tr(Zt);return r.facade=t,Dt(t,nr,r),r},zt=function(t){return ct(t,nr)?t[nr]:{}},Ht=function(t){return ct(t,nr)}}var or,ir={set:Yt,get:zt,has:Ht,enforce:function(t){return Ht(t)?zt(t):Yt(t,{})},getterFor:function(t){return function(r){var e;if(!F(r)||(e=zt(r)).type!==t)throw new tr("Incompatible receiver, "+t+" required");return e}}},ar=r(function(t){var r=Vt.CONFIGURABLE,e=ir.enforce,n=ir.get,o=String,i=Object.defineProperty,c=b("".slice),f=b("".replace),s=b([].join),p=u&&!a(function(){return 8!==i(function(){},"length",{value:8}).length}),l=String(String).split("String"),y=t.exports=function(t,n,a){"Symbol("===c(o(n),0,7)&&(n="["+f(o(n),/^Symbol\(([^)]*)\)/,"$1")+"]"),a&&a.getter&&(n="get "+n),a&&a.setter&&(n="set "+n),(!ct(t,"name")||r&&t.name!==n)&&(u?i(t,"name",{value:n,configurable:!0}):t.name=n),p&&a&&ct(a,"arity")&&t.length!==a.arity&&i(t,"length",{value:a.arity});try{a&&ct(a,"constructor")&&a.constructor?u&&i(t,"prototype",{writable:!1}):t.prototype&&(t.prototype=void 0)}catch(h){}var y=e(t);return ct(y,"source")||(y.source=s(l,"string"==typeof n?n:"")),t};Function.prototype.toString=y(function(){return L(this)&&n(this).source||qt(this)},"toString")}),ur=function(t,r,e,n){n||(n={});var o=n.enumerable,i=void 0!==n.name?n.name:r;if(L(e)&&ar(e,i,n),n.global)o?t[r]=e:rt(r,e);else{try{n.unsafe?t[r]&&(o=!0):delete t[r]}catch(a){}o?t[r]=e:Bt.f(t,r,{value:e,enumerable:!1,configurable:!n.nonConfigurable,writable:!n.nonWritable})}return t},cr=Math.ceil,fr=Math.floor,sr=Math.trunc||function(t){var r=+t;return(r>0?fr:cr)(r)},pr=function(t){var r=+t;return r!=r||0===r?0:sr(r)},lr=Math.max,yr=Math.min,hr=function(t,r){var e=pr(t);return e<0?lr(e+r,0):yr(e,r)},dr=Math.min,vr=function(t){return t>0?dr(pr(t),9007199254740991):0},gr=function(t){return vr(t.length)},br=function(t){return function(r,e,n){var o,i=x(r),a=gr(i),u=hr(n,a);if(t&&e!=e){for(;a>u;)if((o=i[u++])!=o)return!0}else for(;a>u;u++)if((t||u in i)&&i[u]===e)return t||u||0;return!t&&-1}},wr={includes:br(!0),indexOf:br(!1)},mr=wr.indexOf,Ar=b([].push),Tr=function(t,r){var e,n=x(t),o=0,i=[];for(e in n)!ct(Qt,e)&&ct(n,e)&&Ar(i,e);for(;r.length>o;)ct(n,e=r[o++])&&(~mr(i,e)||Ar(i,e));return i},Or=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Er=Or.concat("length","prototype"),Sr={f:Object.getOwnPropertyNames||function(t){return Tr(t,Er)}},jr={f:Object.getOwnPropertySymbols},Rr=b([].concat),xr=U("Reflect","ownKeys")||function(t){var r=Sr.f(Mt(t)),e=jr.f;return e?Rr(r,e(t)):r},Ir=function(t,r,e){for(var n=xr(r),o=Bt.f,i=jt.f,a=0;a<n.length;a++){var u=n[a];ct(t,u)||e&&ct(e,u)||o(t,u,i(r,u))}},Mr=/#|\.prototype\./,Pr=function(t,r){var e=Cr[Lr(t)];return e===Ur||e!==Fr&&(L(r)?a(r):!!r)},Lr=Pr.normalize=function(t){return String(t).replace(Mr,".").toLowerCase()},Cr=Pr.data={},Fr=Pr.NATIVE="N",Ur=Pr.POLYFILL="P",_r=Pr,Br=jt.f,Dr=function(t,r){var e,n,o,a,u,c=t.target,f=t.global,s=t.stat;if(e=f?i:s?i[c]||rt(c,{}):(i[c]||{}).prototype)for(n in r){if(a=r[n],o=t.dontCallGetSet?(u=Br(e,n))&&u.value:e[n],!_r(f?n:c+(s?".":"#")+n,t.forced)&&void 0!==o){if(typeof a==typeof o)continue;Ir(a,o)}(t.sham||o&&o.sham)&&Dt(a,"sham",!0),ur(e,n,a,t)}},kr=!a(function(){function t(){}return t.prototype.constructor=null,Object.getPrototypeOf(new t)!==t.prototype}),Nr=$t("IE_PROTO"),Wr=Object,Vr=Wr.prototype,Gr=kr?Wr.getPrototypeOf:function(t){var r=at(t);if(ct(r,Nr))return r[Nr];var e=r.constructor;return L(e)&&r instanceof e?e.prototype:r instanceof Wr?Vr:null},Yr=String,zr=TypeError,Hr=Object.setPrototypeOf||("__proto__"in{}?function(){var t,r=!1,e={};try{(t=function(t){try{return b($(Object.getOwnPropertyDescriptor(t,"__proto__").set))}catch(r){}}(Object.prototype))(e,[]),r=e instanceof Array}catch(n){}return function(e,n){return Mt(e),function(t){if("object"==typeof t||L(t))return t;throw new zr("Can't set "+Yr(t)+" as a prototype")}(n),r?t(e,n):e.__proto__=n,e}}():void 0),qr=Object.keys||function(t){return Tr(t,Or)},Xr=u&&!Rt?Object.defineProperties:function(t,r){Mt(t);for(var e,n=x(r),o=qr(r),i=o.length,a=0;i>a;)Bt.f(t,e=o[a++],n[e]);return t},Kr={f:Xr},Jr=U("document","documentElement"),$r="prototype",Qr="script",Zr=$t("IE_PROTO"),te=function(){},re=function(t){return"<"+Qr+">"+t+"</"+Qr+">"},ee=function(t){t.write(re("")),t.close();var r=t.parentWindow.Object;return t=null,r},ne=function(){try{or=new ActiveXObject("htmlfile")}catch(o){}var t,r,e;ne="undefined"!=typeof document?document.domain&&or?ee(or):(r=Ot("iframe"),e="java"+Qr+":",r.style.display="none",Jr.appendChild(r),r.src=String(e),(t=r.contentWindow.document).open(),t.write(re("document.F=Object")),t.close(),t.F):ee(or);for(var n=Or.length;n--;)delete ne[$r][Or[n]];return ne()};Qt[Zr]=!0;var oe=Object.create||function(t,r){var e;return null!==t?(te[$r]=Mt(t),e=new te,te[$r]=null,e[Zr]=t):e=ne(),void 0===r?e:Kr.f(e,r)},ie=Error,ae=b("".replace),ue=String(new ie("zxcasd").stack),ce=/\n\s*at [^:]*:[^\n]*/,fe=ce.test(ue),se=!a(function(){var t=new Error("a");return!("stack"in t)||(Object.defineProperty(t,"stack",h(1,7)),7!==t.stack)}),pe=Error.captureStackTrace,le=function(t){if("Function"===A(t))return b(t)},ye=le(le.bind),he=function(t,r){return $(t),void 0===r?t:c?ye(t,r):function(){return t.apply(r,arguments)}},de={},ve=vt("iterator"),ge=Array.prototype,be=function(t){return void 0!==t&&(de.Array===t||ge[ve]===t)},we={};we[vt("toStringTag")]="z";var me="[object z]"===String(we),Ae=vt("toStringTag"),Te=Object,Oe="Arguments"===A(function(){return arguments}()),Ee=me?A:function(t){var r,e,n;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,r){try{return t[r]}catch(e){}}(r=Te(t),Ae))?e:Oe?A(r):"Object"===(n=A(r))&&L(r.callee)?"Arguments":n},Se=vt("iterator"),je=function(t){if(!S(t))return Q(t,Se)||Q(t,"@@iterator")||de[Ee(t)]},Re=TypeError,xe=function(t,r){var e=arguments.length<2?je(t):r;if($(e))return Mt(s(e,t));throw new Re(K(t)+" is not iterable")},Ie=function(t,r,e){var n,o;Mt(t);try{if(!(n=Q(t,"return"))){if("throw"===r)throw e;return e}n=s(n,t)}catch(i){o=!0,n=i}if("throw"===r)throw e;if(o)throw n;return Mt(n),e},Me=TypeError,Pe=function(t,r){this.stopped=t,this.result=r},Le=Pe.prototype,Ce=function(t,r,e){var n,o,i,a,u,c,f,p=e&&e.that,l=!(!e||!e.AS_ENTRIES),y=!(!e||!e.IS_RECORD),h=!(!e||!e.IS_ITERATOR),d=!(!e||!e.INTERRUPTED),v=he(r,p),g=function(t){return n&&Ie(n,"normal",t),new Pe(!0,t)},b=function(t){return l?(Mt(t),d?v(t[0],t[1],g):v(t[0],t[1])):d?v(t,g):v(t)};if(y)n=t.iterator;else if(h)n=t;else{if(!(o=je(t)))throw new Me(K(t)+" is not iterable");if(be(o)){for(i=0,a=gr(t);a>i;i++)if((u=b(t[i]))&&_(Le,u))return u;return new Pe(!1)}n=xe(t,o)}for(c=y?t.next:n.next;!(f=s(c,n)).done;){try{u=b(f.value)}catch(w){Ie(n,"throw",w)}if("object"==typeof u&&u&&_(Le,u))return u}return new Pe(!1)},Fe=String,Ue=function(t){if("Symbol"===Ee(t))throw new TypeError("Cannot convert a Symbol value to a string");return Fe(t)},_e=vt("toStringTag"),Be=Error,De=[].push,ke=function(t,r){var e,n,o,i,a,u,c,f=_(Ne,this);Hr?e=Hr(new Be,f?Gr(this):Ne):(e=f?this:oe(Ne),Dt(e,_e,"Error")),void 0!==r&&Dt(e,"message",function(t,r){return void 0===t?arguments.length<2?"":r:Ue(t)}(r)),i=e,a=ke,u=e.stack,c=1,se&&(pe?pe(i,a):Dt(i,"stack",function(t,r){if(fe&&"string"==typeof t&&!ie.prepareStackTrace)for(;r--;)t=ae(t,ce,"");return t}(u,c))),arguments.length>2&&(n=e,F(o=arguments[2])&&"cause"in o&&Dt(n,"cause",o.cause));var s=[];return Ce(t,De,{that:s}),Dt(e,"errors",s),e};Hr?Hr(ke,Be):Ir(ke,Be,{name:!0});var Ne=ke.prototype=oe(Be.prototype,{constructor:h(1,ke),message:h(1,""),name:h(1,"AggregateError")});Dr({global:!0,constructor:!0,arity:2},{AggregateError:ke});var We=Bt.f,Ve=vt("unscopables"),Ge=Array.prototype;void 0===Ge[Ve]&&We(Ge,Ve,{configurable:!0,value:oe(null)});var Ye,ze,He,qe=function(t){Ge[Ve][t]=!0},Xe=vt("iterator"),Ke=!1;[].keys&&("next"in(He=[].keys())?(ze=Gr(Gr(He)))!==Object.prototype&&(Ye=ze):Ke=!0);var Je=!F(Ye)||a(function(){var t={};return Ye[Xe].call(t)!==t});Je&&(Ye={}),L(Ye[Xe])||ur(Ye,Xe,function(){return this});var $e={IteratorPrototype:Ye,BUGGY_SAFARI_ITERATORS:Ke},Qe=Bt.f,Ze=vt("toStringTag"),tn=function(t,r,e){t&&!e&&(t=t.prototype),t&&!ct(t,Ze)&&Qe(t,Ze,{configurable:!0,value:r})},rn=$e.IteratorPrototype,en=function(){return this},nn=Vt.PROPER,on=Vt.CONFIGURABLE,an=$e.IteratorPrototype,un=$e.BUGGY_SAFARI_ITERATORS,cn=vt("iterator"),fn="keys",sn="values",pn="entries",ln=function(){return this},yn=function(t,r,e,n,o,i,a){!function(t,r,e){var n=r+" Iterator";t.prototype=oe(rn,{next:h(1,e)}),tn(t,n,!1),de[n]=en}(e,r,n);var u,c,f,p=function(t){if(t===o&&g)return g;if(!un&&t&&t in d)return d[t];switch(t){case fn:case sn:case pn:return function(){return new e(this,t)}}return function(){return new e(this)}},l=r+" Iterator",y=!1,d=t.prototype,v=d[cn]||d["@@iterator"]||o&&d[o],g=!un&&v||p(o),b="Array"===r&&d.entries||v;if(b&&(u=Gr(b.call(new t)))!==Object.prototype&&u.next&&(Gr(u)!==an&&(Hr?Hr(u,an):L(u[cn])||ur(u,cn,ln)),tn(u,l,!0)),nn&&o===sn&&v&&v.name!==sn&&(on?Dt(d,"name",sn):(y=!0,g=function(){return s(v,this)})),o)if(c={values:p(sn),keys:i?g:p(fn),entries:p(pn)},a)for(f in c)(un||y||!(f in d))&&ur(d,f,c[f]);else Dr({target:r,proto:!0,forced:un||y},c);return d[cn]!==g&&ur(d,cn,g,{name:o}),de[r]=g,c},hn=function(t,r){return{value:t,done:r}},dn=Bt.f,vn="Array Iterator",gn=ir.set,bn=ir.getterFor(vn),wn=yn(Array,"Array",function(t,r){gn(this,{type:vn,target:x(t),index:0,kind:r})},function(){var t=bn(this),r=t.target,e=t.kind,n=t.index++;if(!r||n>=r.length)return t.target=void 0,hn(void 0,!0);switch(e){case"keys":return hn(n,!1);case"values":return hn(r[n],!1)}return hn([n,r[n]],!1)},"values"),mn=de.Arguments=de.Array;if(qe("keys"),qe("values"),qe("entries"),u&&"values"!==mn.name)try{dn(mn,"name",{value:"values"})}catch(op){}var An=me?{}.toString:function(){return"[object "+Ee(this)+"]"};me||ur(Object.prototype,"toString",An,{unsafe:!0});var Tn="process"===A(i.process),On=function(t,r,e){return e.get&&ar(e.get,r,{getter:!0}),e.set&&ar(e.set,r,{setter:!0}),Bt.f(t,r,e)},En=vt("species"),Sn=function(t){var r=U(t);u&&r&&!r[En]&&On(r,En,{configurable:!0,get:function(){return this}})},jn=TypeError,Rn=function(t,r){if(_(r,t))return t;throw new jn("Incorrect invocation")},xn=function(){},In=[],Mn=U("Reflect","construct"),Pn=/^\s*(?:class|function)\b/,Ln=b(Pn.exec),Cn=!Pn.test(xn),Fn=function(t){if(!L(t))return!1;try{return Mn(xn,In,t),!0}catch(op){return!1}},Un=function(t){if(!L(t))return!1;switch(Ee(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Cn||!!Ln(Pn,qt(t))}catch(op){return!0}};Un.sham=!0;var _n,Bn,Dn,kn,Nn=!Mn||a(function(){var t;return Fn(Fn.call)||!Fn(Object)||!Fn(function(){t=!0})||t})?Un:Fn,Wn=TypeError,Vn=function(t){if(Nn(t))return t;throw new Wn(K(t)+" is not a constructor")},Gn=vt("species"),Yn=function(t,r){var e,n=Mt(t).constructor;return void 0===n||S(e=Mt(n)[Gn])?r:Vn(e)},zn=Function.prototype,Hn=zn.apply,qn=zn.call,Xn="object"==typeof Reflect&&Reflect.apply||(c?qn.bind(Hn):function(){return qn.apply(Hn,arguments)}),Kn=b([].slice),Jn=TypeError,$n=/(?:ipad|iphone|ipod).*applewebkit/i.test(B),Qn=i.setImmediate,Zn=i.clearImmediate,to=i.process,ro=i.Dispatch,eo=i.Function,no=i.MessageChannel,oo=i.String,io=0,ao={},uo="onreadystatechange";a(function(){_n=i.location});var co=function(t){if(ct(ao,t)){var r=ao[t];delete ao[t],r()}},fo=function(t){return function(){co(t)}},so=function(t){co(t.data)},po=function(t){i.postMessage(oo(t),_n.protocol+"//"+_n.host)};Qn&&Zn||(Qn=function(t){!function(t){if(t<1)throw new Jn("Not enough arguments")}(arguments.length);var r=L(t)?t:eo(t),e=Kn(arguments,1);return ao[++io]=function(){Xn(r,void 0,e)},Bn(io),io},Zn=function(t){delete ao[t]},Tn?Bn=function(t){to.nextTick(fo(t))}:ro&&ro.now?Bn=function(t){ro.now(fo(t))}:no&&!$n?(kn=(Dn=new no).port2,Dn.port1.onmessage=so,Bn=he(kn.postMessage,kn)):i.addEventListener&&L(i.postMessage)&&!i.importScripts&&_n&&"file:"!==_n.protocol&&!a(po)?(Bn=po,i.addEventListener("message",so,!1)):Bn=uo in Ot("script")?function(t){Jr.appendChild(Ot("script"))[uo]=function(){Jr.removeChild(this),co(t)}}:function(t){setTimeout(fo(t),0)});var lo={set:Qn,clear:Zn},yo=function(){this.head=null,this.tail=null};yo.prototype={add:function(t){var r={item:t,next:null},e=this.tail;e?e.next=r:this.head=r,this.tail=r},get:function(){var t=this.head;if(t)return null===(this.head=t.next)&&(this.tail=null),t.item}};var ho,vo,go,bo,wo,mo=yo,Ao=/ipad|iphone|ipod/i.test(B)&&"undefined"!=typeof Pebble,To=/web0s(?!.*chrome)/i.test(B),Oo=jt.f,Eo=lo.set,So=i.MutationObserver||i.WebKitMutationObserver,jo=i.document,Ro=i.process,xo=i.Promise,Io=Oo(i,"queueMicrotask"),Mo=Io&&Io.value;if(!Mo){var Po=new mo,Lo=function(){var t,r;for(Tn&&(t=Ro.domain)&&t.exit();r=Po.get();)try{r()}catch(op){throw Po.head&&ho(),op}t&&t.enter()};$n||Tn||To||!So||!jo?!Ao&&xo&&xo.resolve?((bo=xo.resolve(void 0)).constructor=xo,wo=he(bo.then,bo),ho=function(){wo(Lo)}):Tn?ho=function(){Ro.nextTick(Lo)}:(Eo=he(Eo,i),ho=function(){Eo(Lo)}):(vo=!0,go=jo.createTextNode(""),new So(Lo).observe(go,{characterData:!0}),ho=function(){go.data=vo=!vo}),Mo=function(t){Po.head||ho(),Po.add(t)}}var Co=Mo,Fo=function(t){try{return{error:!1,value:t()}}catch(op){return{error:!0,value:op}}},Uo=i.Promise,_o="object"==typeof Deno&&Deno&&"object"==typeof Deno.version,Bo=!_o&&!Tn&&"object"==typeof window&&"object"==typeof document;Uo&&Uo.prototype;var Do,ko,No,Wo=vt("species"),Vo=!1,Go=L(i.PromiseRejectionEvent),Yo=_r("Promise",function(){var t=qt(Uo),r=t!==String(Uo);if(!r&&66===V)return!0;if(!V||V<51||!/native code/.test(t)){var e=new Uo(function(t){t(1)}),n=function(t){t(function(){},function(){})};if((e.constructor={})[Wo]=n,!(Vo=e.then(function(){})instanceof n))return!0}return!r&&(Bo||_o)&&!Go}),zo={CONSTRUCTOR:Yo,REJECTION_EVENT:Go,SUBCLASSING:Vo},Ho=TypeError,qo=function(t){var r,e;this.promise=new t(function(t,n){if(void 0!==r||void 0!==e)throw new Ho("Bad Promise constructor");r=t,e=n}),this.resolve=$(r),this.reject=$(e)},Xo={f:function(t){return new qo(t)}},Ko=lo.set,Jo="Promise",$o=zo.CONSTRUCTOR,Qo=zo.REJECTION_EVENT,Zo=zo.SUBCLASSING,ti=ir.getterFor(Jo),ri=ir.set,ei=Uo&&Uo.prototype,ni=Uo,oi=ei,ii=i.TypeError,ai=i.document,ui=i.process,ci=Xo.f,fi=ci,si=!!(ai&&ai.createEvent&&i.dispatchEvent),pi="unhandledrejection",li=function(t){var r;return!(!F(t)||!L(r=t.then))&&r},yi=function(t,r){var e,n,o,i=r.value,a=1===r.state,u=a?t.ok:t.fail,c=t.resolve,f=t.reject,p=t.domain;try{u?(a||(2===r.rejection&&bi(r),r.rejection=1),!0===u?e=i:(p&&p.enter(),e=u(i),p&&(p.exit(),o=!0)),e===t.promise?f(new ii("Promise-chain cycle")):(n=li(e))?s(n,e,c,f):c(e)):f(i)}catch(op){p&&!o&&p.exit(),f(op)}},hi=function(t,r){t.notified||(t.notified=!0,Co(function(){for(var e,n=t.reactions;e=n.get();)yi(e,t);t.notified=!1,r&&!t.rejection&&vi(t)}))},di=function(t,r,e){var n,o;si?((n=ai.createEvent("Event")).promise=r,n.reason=e,n.initEvent(t,!1,!0),i.dispatchEvent(n)):n={promise:r,reason:e},!Qo&&(o=i["on"+t])?o(n):t===pi&&function(t,r){try{1===arguments.length?console.error(t):console.error(t,r)}catch(op){}}("Unhandled promise rejection",e)},vi=function(t){s(Ko,i,function(){var r,e=t.facade,n=t.value;if(gi(t)&&(r=Fo(function(){Tn?ui.emit("unhandledRejection",n,e):di(pi,e,n)}),t.rejection=Tn||gi(t)?2:1,r.error))throw r.value})},gi=function(t){return 1!==t.rejection&&!t.parent},bi=function(t){s(Ko,i,function(){var r=t.facade;Tn?ui.emit("rejectionHandled",r):di("rejectionhandled",r,t.value)})},wi=function(t,r,e){return function(n){t(r,n,e)}},mi=function(t,r,e){t.done||(t.done=!0,e&&(t=e),t.value=r,t.state=2,hi(t,!0))},Ai=function(t,r,e){if(!t.done){t.done=!0,e&&(t=e);try{if(t.facade===r)throw new ii("Promise can't be resolved itself");var n=li(r);n?Co(function(){var e={done:!1};try{s(n,r,wi(Ai,e,t),wi(mi,e,t))}catch(op){mi(e,op,t)}}):(t.value=r,t.state=1,hi(t,!1))}catch(op){mi({done:!1},op,t)}}};if($o&&(oi=(ni=function(t){Rn(this,oi),$(t),s(Do,this);var r=ti(this);try{t(wi(Ai,r),wi(mi,r))}catch(op){mi(r,op)}}).prototype,(Do=function(t){ri(this,{type:Jo,done:!1,notified:!1,parent:!1,reactions:new mo,rejection:!1,state:0,value:void 0})}).prototype=ur(oi,"then",function(t,r){var e=ti(this),n=ci(Yn(this,ni));return e.parent=!0,n.ok=!L(t)||t,n.fail=L(r)&&r,n.domain=Tn?ui.domain:void 0,0===e.state?e.reactions.add(n):Co(function(){yi(n,e)}),n.promise}),ko=function(){var t=new Do,r=ti(t);this.promise=t,this.resolve=wi(Ai,r),this.reject=wi(mi,r)},Xo.f=ci=function(t){return t===ni||void 0===t?new ko(t):fi(t)},L(Uo)&&ei!==Object.prototype)){No=ei.then,Zo||ur(ei,"then",function(t,r){var e=this;return new ni(function(t,r){s(No,e,t,r)}).then(t,r)},{unsafe:!0});try{delete ei.constructor}catch(op){}Hr&&Hr(ei,oi)}Dr({global:!0,constructor:!0,wrap:!0,forced:$o},{Promise:ni}),tn(ni,Jo,!1),Sn(Jo);var Ti=vt("iterator"),Oi=!1;try{var Ei=0,Si={next:function(){return{done:!!Ei++}},return:function(){Oi=!0}};Si[Ti]=function(){return this},Array.from(Si,function(){throw 2})}catch(op){}var ji=function(t,r){try{if(!r&&!Oi)return!1}catch(op){return!1}var e=!1;try{var n={};n[Ti]=function(){return{next:function(){return{done:e=!0}}}},t(n)}catch(op){}return e},Ri=zo.CONSTRUCTOR||!ji(function(t){Uo.all(t).then(void 0,function(){})});Dr({target:"Promise",stat:!0,forced:Ri},{all:function(t){var r=this,e=Xo.f(r),n=e.resolve,o=e.reject,i=Fo(function(){var e=$(r.resolve),i=[],a=0,u=1;Ce(t,function(t){var c=a++,f=!1;u++,s(e,r,t).then(function(t){f||(f=!0,i[c]=t,--u||n(i))},o)}),--u||n(i)});return i.error&&o(i.value),e.promise}});var xi=zo.CONSTRUCTOR,Ii=Uo&&Uo.prototype;if(Dr({target:"Promise",proto:!0,forced:xi,real:!0},{catch:function(t){return this.then(void 0,t)}}),L(Uo)){var Mi=U("Promise").prototype.catch;Ii.catch!==Mi&&ur(Ii,"catch",Mi,{unsafe:!0})}Dr({target:"Promise",stat:!0,forced:Ri},{race:function(t){var r=this,e=Xo.f(r),n=e.reject,o=Fo(function(){var o=$(r.resolve);Ce(t,function(t){s(o,r,t).then(e.resolve,n)})});return o.error&&n(o.value),e.promise}}),Dr({target:"Promise",stat:!0,forced:zo.CONSTRUCTOR},{reject:function(t){var r=Xo.f(this);return s(r.reject,void 0,t),r.promise}});var Pi=function(t,r){if(Mt(t),F(r)&&r.constructor===t)return r;var e=Xo.f(t);return(0,e.resolve)(r),e.promise},Li=zo.CONSTRUCTOR;U("Promise"),Dr({target:"Promise",stat:!0,forced:Li},{resolve:function(t){return Pi(this,t)}}),Dr({target:"Promise",stat:!0,forced:Ri},{allSettled:function(t){var r=this,e=Xo.f(r),n=e.resolve,o=e.reject,i=Fo(function(){var e=$(r.resolve),o=[],i=0,a=1;Ce(t,function(t){var u=i++,c=!1;a++,s(e,r,t).then(function(t){c||(c=!0,o[u]={status:"fulfilled",value:t},--a||n(o))},function(t){c||(c=!0,o[u]={status:"rejected",reason:t},--a||n(o))})}),--a||n(o)});return i.error&&o(i.value),e.promise}});var Ci="No one promise resolved";Dr({target:"Promise",stat:!0,forced:Ri},{any:function(t){var r=this,e=U("AggregateError"),n=Xo.f(r),o=n.resolve,i=n.reject,a=Fo(function(){var n=$(r.resolve),a=[],u=0,c=1,f=!1;Ce(t,function(t){var p=u++,l=!1;c++,s(n,r,t).then(function(t){l||f||(f=!0,o(t))},function(t){l||f||(l=!0,a[p]=t,--c||i(new e(a,Ci)))})}),--c||i(new e(a,Ci))});return a.error&&i(a.value),n.promise}});var Fi=Uo&&Uo.prototype,Ui=!!Uo&&a(function(){Fi.finally.call({then:function(){}},function(){})});if(Dr({target:"Promise",proto:!0,real:!0,forced:Ui},{finally:function(t){var r=Yn(this,U("Promise")),e=L(t);return this.then(e?function(e){return Pi(r,t()).then(function(){return e})}:t,e?function(e){return Pi(r,t()).then(function(){throw e})}:t)}}),L(Uo)){var _i=U("Promise").prototype.finally;Fi.finally!==_i&&ur(Fi,"finally",_i,{unsafe:!0})}var Bi=b("".charAt),Di=b("".charCodeAt),ki=b("".slice),Ni=function(t){return function(r,e){var n,o,i=Ue(R(r)),a=pr(e),u=i.length;return a<0||a>=u?t?"":void 0:(n=Di(i,a))<55296||n>56319||a+1===u||(o=Di(i,a+1))<56320||o>57343?t?Bi(i,a):n:t?ki(i,a,a+2):o-56320+(n-55296<<10)+65536}},Wi=(Ni(!1),Ni(!0)),Vi="String Iterator",Gi=ir.set,Yi=ir.getterFor(Vi);yn(String,"String",function(t){Gi(this,{type:Vi,string:Ue(t),index:0})},function(){var t,r=Yi(this),e=r.string,n=r.index;return n>=e.length?hn(void 0,!0):(t=Wi(e,n),r.index+=t.length,hn(t,!1))});var zi=i;zi.Promise;var Hi=Array.isArray||function(t){return"Array"===A(t)},qi=vt("species"),Xi=Array,Ki=function(t,r){return new(function(t){var r;return Hi(t)&&(r=t.constructor,(Nn(r)&&(r===Xi||Hi(r.prototype))||F(r)&&null===(r=r[qi]))&&(r=void 0)),void 0===r?Xi:r}(t))(0===r?0:r)},Ji=b([].push),$i=function(t){var r=1===t,e=2===t,n=3===t,o=4===t,i=6===t,a=7===t,u=5===t||i;return function(c,f,s,p){for(var l,y,h=at(c),d=E(h),v=he(f,s),g=gr(d),b=0,w=p||Ki,m=r?w(c,g):e||a?w(c,0):void 0;g>b;b++)if((u||b in d)&&(y=v(l=d[b],b,h),t))if(r)m[b]=y;else if(y)switch(t){case 3:return!0;case 5:return l;case 6:return b;case 2:Ji(m,l)}else switch(t){case 4:return!1;case 7:Ji(m,l)}return i?-1:n||o?o:m}},Qi={forEach:$i(0),map:$i(1),filter:$i(2),some:$i(3),every:$i(4),find:$i(5),findIndex:$i(6),filterReject:$i(7)},Zi=vt("species"),ta=Qi.map,ra=V>=51||!a(function(){var t=[];return(t.constructor={})[Zi]=function(){return{foo:1}},1!==t.map(Boolean).foo});Dr({target:"Array",proto:!0,forced:!ra},{map:function(t){return ta(this,t,arguments.length>1?arguments[1]:void 0)}});var ea=function(t,r){return b(i[t].prototype[r])};ea("Array","map"),Dr({target:"Array",stat:!0},{isArray:Hi}),zi.Array.isArray;var na=TypeError,oa=function(t){return function(r,e,n,o){$(e);var i=at(r),a=E(i),u=gr(i),c=t?u-1:0,f=t?-1:1;if(n<2)for(;;){if(c in a){o=a[c],c+=f;break}if(c+=f,t?c<0:u<=c)throw new na("Reduce of empty array with no initial value")}for(;t?c>=0:u>c;c+=f)c in a&&(o=e(o,a[c],c,i));return o}},ia={left:oa(!1),right:oa(!0)},aa=function(t,r){var e=[][t];return!!e&&a(function(){e.call(null,r||function(){return 1},1)})},ua=ia.left,ca=!Tn&&V>79&&V<83||!aa("reduce");Dr({target:"Array",proto:!0,forced:ca},{reduce:function(t){var r=arguments.length;return ua(this,t,r,r>1?arguments[1]:void 0)}}),ea("Array","reduce");var fa=Qi.forEach,sa=aa("forEach")?[].forEach:function(t){return fa(this,t,arguments.length>1?arguments[1]:void 0)};Dr({target:"Array",proto:!0,forced:[].forEach!==sa},{forEach:sa}),ea("Array","forEach");var pa=Qi.find,la="find",ya=!0;la in[]&&Array(1)[la](function(){ya=!1}),Dr({target:"Array",proto:!0,forced:ya},{find:function(t){return pa(this,t,arguments.length>1?arguments[1]:void 0)}}),qe(la),ea("Array","find"),Dr({target:"Object",stat:!0,sham:!u},{create:oe}),zi.Object;var ha=a(function(){qr(1)});Dr({target:"Object",stat:!0,forced:ha},{keys:function(t){return qr(at(t))}}),zi.Object.keys;var da=b(y.f),va=b([].push),ga=u&&a(function(){var t=Object.create(null);return t[2]=2,!da(t,2)}),ba=function(t){return function(r){for(var e,n=x(r),o=qr(n),i=ga&&null===Gr(n),a=o.length,c=0,f=[];a>c;)e=o[c++],u&&!(i?e in n:da(n,e))||va(f,t?[e,n[e]]:n[e]);return f}},wa=(ba(!0),ba(!1));Dr({target:"Object",stat:!0},{values:function(t){return wa(t)}}),zi.Object.values;var ma=Object.assign,Aa=Object.defineProperty,Ta=b([].concat),Oa=!ma||a(function(){if(u&&1!==ma({b:1},ma(Aa({},"a",{enumerable:!0,get:function(){Aa(this,"b",{value:3,enumerable:!1})}}),{b:2})).b)return!0;var t={},r={},e=Symbol("assign detection"),n="abcdefghijklmnopqrst";return t[e]=7,n.split("").forEach(function(t){r[t]=t}),7!==ma({},t)[e]||qr(ma({},r)).join("")!==n})?function(t,r){for(var e=at(t),n=arguments.length,o=1,i=jr.f,a=y.f;n>o;)for(var c,f=E(arguments[o++]),p=i?Ta(qr(f),i(f)):qr(f),l=p.length,h=0;l>h;)c=p[h++],u&&!s(a,f,c)||(e[c]=f[c]);return e}:ma;Dr({target:"Object",stat:!0,arity:2,forced:Object.assign!==Oa},{assign:Oa}),zi.Object.assign;var Ea="\t\n\v\f\r                　\u2028\u2029\ufeff",Sa=b("".replace),ja=RegExp("^["+Ea+"]+"),Ra=RegExp("(^|[^"+Ea+"])["+Ea+"]+$"),xa=function(t){return function(r){var e=Ue(R(r));return 1&t&&(e=Sa(e,ja,"")),2&t&&(e=Sa(e,Ra,"$1")),e}},Ia={start:xa(1),end:xa(2),trim:xa(3)},Ma=Vt.PROPER,Pa=function(t){return a(function(){return!!Ea[t]()||"​᠎"!=="​᠎"[t]()||Ma&&Ea[t].name!==t})},La=Ia.trim;Dr({target:"String",proto:!0,forced:Pa("trim")},{trim:function(){return La(this)}}),ea("String","trim");var Ca=Ia.start,Fa=Pa("trimStart")?function(){return Ca(this)}:"".trimStart;Dr({target:"String",proto:!0,name:"trimStart",forced:"".trimLeft!==Fa},{trimLeft:Fa}),Dr({target:"String",proto:!0,name:"trimStart",forced:"".trimStart!==Fa},{trimStart:Fa}),ea("String","trimLeft");var Ua=Ia.end,_a=Pa("trimEnd")?function(){return Ua(this)}:"".trimEnd;Dr({target:"String",proto:!0,name:"trimEnd",forced:"".trimRight!==_a},{trimRight:_a}),Dr({target:"String",proto:!0,name:"trimEnd",forced:"".trimEnd!==_a},{trimEnd:_a}),ea("String","trimRight");var Ba=Math.floor,Da=Number.isInteger||function(t){return!F(t)&&isFinite(t)&&Ba(t)===t};Dr({target:"Number",stat:!0},{isInteger:Da}),zi.Number.isInteger;var ka="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,Na=function(t,r,e){for(var n in r)ur(t,n,r[n],e);return t},Wa=RangeError,Va=function(t){if(void 0===t)return 0;var r=pr(t),e=vr(r);if(r!==e)throw new Wa("Wrong length or index");return e},Ga=Math.sign||function(t){var r=+t;return 0===r||r!=r?r:r<0?-1:1},Ya=Math.abs,za=2220446049250313e-31,Ha=1/za,qa=Math.fround||function(t){return function(t,r,e,n){var o=+t,i=Ya(o),a=Ga(o);if(i<n)return a*function(t){return t+Ha-Ha}(i/n/r)*n*r;var u=(1+r/za)*i,c=u-(u-i);return c>e||c!=c?a*(1/0):a*c}(t,1.1920928955078125e-7,34028234663852886e22,11754943508222875e-54)},Xa=Array,Ka=Math.abs,Ja=Math.pow,$a=Math.floor,Qa=Math.log,Za=Math.LN2,tu=function(t){for(var r=at(this),e=gr(r),n=arguments.length,o=hr(n>1?arguments[1]:void 0,e),i=n>2?arguments[2]:void 0,a=void 0===i?e:hr(i,e);a>o;)r[o++]=t;return r},ru=function(t,r,e){var n=mt(r);n in t?Bt.f(t,n,h(0,e)):t[n]=e},eu=Array,nu=Math.max,ou=function(t,r,e){for(var n=gr(t),o=hr(r,n),i=hr(void 0===e?n:e,n),a=eu(nu(i-o,0)),u=0;o<i;o++,u++)ru(a,u,t[o]);return a.length=u,a},iu=Sr.f,au=Vt.PROPER,uu=Vt.CONFIGURABLE,cu="ArrayBuffer",fu="DataView",su="prototype",pu="Wrong index",lu=ir.getterFor(cu),yu=ir.getterFor(fu),hu=ir.set,du=i[cu],vu=du,gu=vu&&vu[su],bu=i[fu],wu=bu&&bu[su],mu=Object.prototype,Au=i.Array,Tu=i.RangeError,Ou=b(tu),Eu=b([].reverse),Su=function(t,r,e){var n,o,i,a=Xa(e),u=8*e-r-1,c=(1<<u)-1,f=c>>1,s=23===r?Ja(2,-24)-Ja(2,-77):0,p=t<0||0===t&&1/t<0?1:0,l=0;for((t=Ka(t))!=t||t===1/0?(o=t!=t?1:0,n=c):(n=$a(Qa(t)/Za),t*(i=Ja(2,-n))<1&&(n--,i*=2),(t+=n+f>=1?s/i:s*Ja(2,1-f))*i>=2&&(n++,i/=2),n+f>=c?(o=0,n=c):n+f>=1?(o=(t*i-1)*Ja(2,r),n+=f):(o=t*Ja(2,f-1)*Ja(2,r),n=0));r>=8;)a[l++]=255&o,o/=256,r-=8;for(n=n<<r|o,u+=r;u>0;)a[l++]=255&n,n/=256,u-=8;return a[--l]|=128*p,a},ju=function(t,r){var e,n=t.length,o=8*n-r-1,i=(1<<o)-1,a=i>>1,u=o-7,c=n-1,f=t[c--],s=127&f;for(f>>=7;u>0;)s=256*s+t[c--],u-=8;for(e=s&(1<<-u)-1,s>>=-u,u+=r;u>0;)e=256*e+t[c--],u-=8;if(0===s)s=1-a;else{if(s===i)return e?NaN:f?-1/0:1/0;e+=Ja(2,r),s-=a}return(f?-1:1)*e*Ja(2,s-r)},Ru=function(t){return[255&t]},xu=function(t){return[255&t,t>>8&255]},Iu=function(t){return[255&t,t>>8&255,t>>16&255,t>>24&255]},Mu=function(t){return t[3]<<24|t[2]<<16|t[1]<<8|t[0]},Pu=function(t){return Su(qa(t),23,4)},Lu=function(t){return Su(t,52,8)},Cu=function(t,r,e){On(t[su],r,{configurable:!0,get:function(){return e(this)[r]}})},Fu=function(t,r,e,n){var o=yu(t),i=Va(e),a=!!n;if(i+r>o.byteLength)throw new Tu(pu);var u=o.bytes,c=i+o.byteOffset,f=ou(u,c,c+r);return a?f:Eu(f)},Uu=function(t,r,e,n,o,i){var a=yu(t),u=Va(e),c=n(+o),f=!!i;if(u+r>a.byteLength)throw new Tu(pu);for(var s=a.bytes,p=u+a.byteOffset,l=0;l<r;l++)s[p+l]=c[f?l:r-l-1]};if(ka){var _u=au&&du.name!==cu;if(a(function(){du(1)})&&a(function(){new du(-1)})&&!a(function(){return new du,new du(1.5),new du(NaN),1!==du.length||_u&&!uu}))_u&&uu&&Dt(du,"name",cu);else{(vu=function(t){return Rn(this,gu),new du(Va(t))})[su]=gu;for(var Bu,Du=iu(du),ku=0;Du.length>ku;)(Bu=Du[ku++])in vu||Dt(vu,Bu,du[Bu]);gu.constructor=vu}Hr&&Gr(wu)!==mu&&Hr(wu,mu);var Nu=new bu(new vu(2)),Wu=b(wu.setInt8);Nu.setInt8(0,2147483648),Nu.setInt8(1,2147483649),!Nu.getInt8(0)&&Nu.getInt8(1)||Na(wu,{setInt8:function(t,r){Wu(this,t,r<<24>>24)},setUint8:function(t,r){Wu(this,t,r<<24>>24)}},{unsafe:!0})}else gu=(vu=function(t){Rn(this,gu);var r=Va(t);hu(this,{type:cu,bytes:Ou(Au(r),0),byteLength:r}),u||(this.byteLength=r,this.detached=!1)})[su],wu=(bu=function(t,r,e){Rn(this,wu),Rn(t,gu);var n=lu(t),o=n.byteLength,i=pr(r);if(i<0||i>o)throw new Tu("Wrong offset");if(i+(e=void 0===e?o-i:vr(e))>o)throw new Tu("Wrong length");hu(this,{type:fu,buffer:t,byteLength:e,byteOffset:i,bytes:n.bytes}),u||(this.buffer=t,this.byteLength=e,this.byteOffset=i)})[su],u&&(Cu(vu,"byteLength",lu),Cu(bu,"buffer",yu),Cu(bu,"byteLength",yu),Cu(bu,"byteOffset",yu)),Na(wu,{getInt8:function(t){return Fu(this,1,t)[0]<<24>>24},getUint8:function(t){return Fu(this,1,t)[0]},getInt16:function(t){var r=Fu(this,2,t,arguments.length>1&&arguments[1]);return(r[1]<<8|r[0])<<16>>16},getUint16:function(t){var r=Fu(this,2,t,arguments.length>1&&arguments[1]);return r[1]<<8|r[0]},getInt32:function(t){return Mu(Fu(this,4,t,arguments.length>1&&arguments[1]))},getUint32:function(t){return Mu(Fu(this,4,t,arguments.length>1&&arguments[1]))>>>0},getFloat32:function(t){return ju(Fu(this,4,t,arguments.length>1&&arguments[1]),23)},getFloat64:function(t){return ju(Fu(this,8,t,arguments.length>1&&arguments[1]),52)},setInt8:function(t,r){Uu(this,1,t,Ru,r)},setUint8:function(t,r){Uu(this,1,t,Ru,r)},setInt16:function(t,r){Uu(this,2,t,xu,r,arguments.length>2&&arguments[2])},setUint16:function(t,r){Uu(this,2,t,xu,r,arguments.length>2&&arguments[2])},setInt32:function(t,r){Uu(this,4,t,Iu,r,arguments.length>2&&arguments[2])},setUint32:function(t,r){Uu(this,4,t,Iu,r,arguments.length>2&&arguments[2])},setFloat32:function(t,r){Uu(this,4,t,Pu,r,arguments.length>2&&arguments[2])},setFloat64:function(t,r){Uu(this,8,t,Lu,r,arguments.length>2&&arguments[2])}});tn(vu,cu),tn(bu,fu);var Vu={ArrayBuffer:vu,DataView:bu},Gu="ArrayBuffer",Yu=Vu[Gu],zu=i[Gu];Dr({global:!0,constructor:!0,forced:zu!==Yu},{ArrayBuffer:Yu}),Sn(Gu);var Hu=Vu.ArrayBuffer,qu=Vu.DataView,Xu=qu.prototype,Ku=le(Hu.prototype.slice),Ju=le(Xu.getUint8),$u=le(Xu.setUint8),Qu=a(function(){return!new Hu(2).slice(1,void 0).byteLength});Dr({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:Qu},{slice:function(t,r){if(Ku&&void 0===r)return Ku(Mt(this),t);for(var e=Mt(this).byteLength,n=hr(t,e),o=hr(void 0===r?e:r,e),i=new(Yn(this,Hu))(vr(o-n)),a=new qu(this),u=new qu(i),c=0;n<o;)$u(u,c++,Ju(a,n++));return i}});var Zu,tc,rc,ec=ir.enforce,nc=ir.get,oc=i.Int8Array,ic=oc&&oc.prototype,ac=i.Uint8ClampedArray,uc=ac&&ac.prototype,cc=oc&&Gr(oc),fc=ic&&Gr(ic),sc=Object.prototype,pc=i.TypeError,lc=vt("toStringTag"),yc=lt("TYPED_ARRAY_TAG"),hc="TypedArrayConstructor",dc=ka&&!!Hr&&"Opera"!==Ee(i.opera),vc=!1,gc={Int8Array:1,Uint8Array:1,Uint8ClampedArray:1,Int16Array:2,Uint16Array:2,Int32Array:4,Uint32Array:4,Float32Array:4,Float64Array:8},bc={BigInt64Array:8,BigUint64Array:8},wc=function(t){var r=Gr(t);if(F(r)){var e=nc(r);return e&&ct(e,hc)?e[hc]:wc(r)}},mc=function(t){if(!F(t))return!1;var r=Ee(t);return ct(gc,r)||ct(bc,r)};for(Zu in gc)(rc=(tc=i[Zu])&&tc.prototype)?ec(rc)[hc]=tc:dc=!1;for(Zu in bc)(rc=(tc=i[Zu])&&tc.prototype)&&(ec(rc)[hc]=tc);if((!dc||!L(cc)||cc===Function.prototype)&&(cc=function(){throw new pc("Incorrect invocation")},dc))for(Zu in gc)i[Zu]&&Hr(i[Zu],cc);if((!dc||!fc||fc===sc)&&(fc=cc.prototype,dc))for(Zu in gc)i[Zu]&&Hr(i[Zu].prototype,fc);if(dc&&Gr(uc)!==fc&&Hr(uc,fc),u&&!ct(fc,lc))for(Zu in vc=!0,On(fc,lc,{configurable:!0,get:function(){return F(this)?this[yc]:void 0}}),gc)i[Zu]&&Dt(i[Zu],yc,Zu);var Ac={NATIVE_ARRAY_BUFFER_VIEWS:dc,TYPED_ARRAY_TAG:vc&&yc,aTypedArray:function(t){if(mc(t))return t;throw new pc("Target is not a typed array")},aTypedArrayConstructor:function(t){if(L(t)&&(!Hr||_(cc,t)))return t;throw new pc(K(t)+" is not a typed array constructor")},exportTypedArrayMethod:function(t,r,e,n){if(u){if(e)for(var o in gc){var a=i[o];if(a&&ct(a.prototype,t))try{delete a.prototype[t]}catch(op){try{a.prototype[t]=r}catch(c){}}}fc[t]&&!e||ur(fc,t,e?r:dc&&ic[t]||r,n)}},exportTypedArrayStaticMethod:function(t,r,e){var n,o;if(u){if(Hr){if(e)for(n in gc)if((o=i[n])&&ct(o,t))try{delete o[t]}catch(op){}if(cc[t]&&!e)return;try{return ur(cc,t,e?r:dc&&cc[t]||r)}catch(op){}}for(n in gc)!(o=i[n])||o[t]&&!e||ur(o,t,r)}},getTypedArrayConstructor:wc,isView:function(t){if(!F(t))return!1;var r=Ee(t);return"DataView"===r||ct(gc,r)||ct(bc,r)},isTypedArray:mc,TypedArray:cc,TypedArrayPrototype:fc},Tc=Ac.NATIVE_ARRAY_BUFFER_VIEWS,Oc=i.ArrayBuffer,Ec=i.Int8Array,Sc=!Tc||!a(function(){Ec(1)})||!a(function(){new Ec(-1)})||!ji(function(t){new Ec,new Ec(null),new Ec(1.5),new Ec(t)},!0)||a(function(){return 1!==new Ec(new Oc(2),1,void 0).length}),jc=RangeError,Rc=RangeError,xc=function(t,r){var e=function(t){var r=pr(t);if(r<0)throw new jc("The argument can't be less than 0");return r}(t);if(e%r)throw new Rc("Wrong offset");return e},Ic=Math.round,Mc=function(t){var r=Ee(t);return"BigInt64Array"===r||"BigUint64Array"===r},Pc=TypeError,Lc=function(t){var r=wt(t,"number");if("number"==typeof r)throw new Pc("Can't convert number to bigint");return BigInt(r)},Cc=Ac.aTypedArrayConstructor,Fc=function(t){var r,e,n,o,i,a,u,c,f=Vn(this),p=at(t),l=arguments.length,y=l>1?arguments[1]:void 0,h=void 0!==y,d=je(p);if(d&&!be(d))for(c=(u=xe(p,d)).next,p=[];!(a=s(c,u)).done;)p.push(a.value);for(h&&l>2&&(y=he(y,arguments[2])),e=gr(p),n=new(Cc(f))(e),o=Mc(n),r=0;e>r;r++)i=h?y(p[r],r):p[r],n[r]=o?Lc(i):+i;return n},Uc=r(function(t){var r=Sr.f,e=Qi.forEach,n=ir.get,o=ir.set,a=ir.enforce,c=Bt.f,f=jt.f,p=i.RangeError,l=Vu.ArrayBuffer,y=l.prototype,d=Vu.DataView,v=Ac.NATIVE_ARRAY_BUFFER_VIEWS,g=Ac.TYPED_ARRAY_TAG,b=Ac.TypedArray,w=Ac.TypedArrayPrototype,m=Ac.aTypedArrayConstructor,A=Ac.isTypedArray,T="BYTES_PER_ELEMENT",O="Wrong length",E=function(t,r){m(t);for(var e=0,n=r.length,o=new t(n);n>e;)o[e]=r[e++];return o},S=function(t,r){On(t,r,{configurable:!0,get:function(){return n(this)[r]}})},j=function(t){var r;return _(y,t)||"ArrayBuffer"===(r=Ee(t))||"SharedArrayBuffer"===r},R=function(t,r){return A(t)&&!q(r)&&r in t&&Da(+r)&&r>=0},x=function(t,r){return r=mt(r),R(t,r)?h(2,t[r]):f(t,r)},I=function(t,r,e){return r=mt(r),!(R(t,r)&&F(e)&&ct(e,"value"))||ct(e,"get")||ct(e,"set")||e.configurable||ct(e,"writable")&&!e.writable||ct(e,"enumerable")&&!e.enumerable?c(t,r,e):(t[r]=e.value,t)};u?(v||(jt.f=x,Bt.f=I,S(w,"buffer"),S(w,"byteOffset"),S(w,"byteLength"),S(w,"length")),Dr({target:"Object",stat:!0,forced:!v},{getOwnPropertyDescriptor:x,defineProperty:I}),t.exports=function(t,u,f){var y=t.match(/\d+/)[0]/8,h=t+(f?"Clamped":"")+"Array",m="get"+t,S="set"+t,R=i[h],x=R,I=x&&x.prototype,M={},P=function(t,r){c(t,r,{get:function(){return function(t,r){var e=n(t);return e.view[m](r*y+e.byteOffset,!0)}(this,r)},set:function(t){return function(t,r,e){var o=n(t);o.view[S](r*y+o.byteOffset,f?function(t){var r=Ic(t);return r<0?0:r>255?255:255&r}(e):e,!0)}(this,r,t)},enumerable:!0})};v?Sc&&(x=u(function(t,r,e,n){return Rn(t,I),function(t,r,e){var n,o;return Hr&&L(n=r.constructor)&&n!==e&&F(o=n.prototype)&&o!==e.prototype&&Hr(t,o),t}(F(r)?j(r)?void 0!==n?new R(r,xc(e,y),n):void 0!==e?new R(r,xc(e,y)):new R(r):A(r)?E(x,r):s(Fc,x,r):new R(Va(r)),t,x)}),Hr&&Hr(x,b),e(r(R),function(t){t in x||Dt(x,t,R[t])}),x.prototype=I):(x=u(function(t,r,e,n){Rn(t,I);var i,a,u,c=0,f=0;if(F(r)){if(!j(r))return A(r)?E(x,r):s(Fc,x,r);i=r,f=xc(e,y);var h=r.byteLength;if(void 0===n){if(h%y)throw new p(O);if((a=h-f)<0)throw new p(O)}else if((a=vr(n)*y)+f>h)throw new p(O);u=a/y}else u=Va(r),i=new l(a=u*y);for(o(t,{buffer:i,byteOffset:f,byteLength:a,length:u,view:new d(i)});c<u;)P(t,c++)}),Hr&&Hr(x,b),I=x.prototype=oe(w)),I.constructor!==x&&Dt(I,"constructor",x),a(I).TypedArrayConstructor=x,g&&Dt(I,g,h);var C=x!==R;M[h]=x,Dr({global:!0,constructor:!0,forced:C,sham:!v},M),T in x||Dt(x,T,y),T in I||Dt(I,T,y),Sn(h)}):t.exports=function(){}});Uc("Uint8",function(t){return function(r,e,n){return t(this,r,e,n)}}),(0,Ac.exportTypedArrayStaticMethod)("from",Fc,Sc);var _c=Ac.aTypedArrayConstructor;(0,Ac.exportTypedArrayStaticMethod)("of",function(){for(var t=0,r=arguments.length,e=new(_c(this))(r);r>t;)e[t]=arguments[t++];return e},Sc);var Bc=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("at",function(t){var r=Bc(this),e=gr(r),n=pr(t),o=n>=0?n:e+n;return o<0||o>=e?void 0:r[o]});var Dc=TypeError,kc=function(t,r){if(!delete t[r])throw new Dc("Cannot delete property "+K(r)+" of "+K(t))},Nc=Math.min,Wc=[].copyWithin||function(t,r){var e=at(this),n=gr(e),o=hr(t,n),i=hr(r,n),a=arguments.length>2?arguments[2]:void 0,u=Nc((void 0===a?n:hr(a,n))-i,n-o),c=1;for(i<o&&o<i+u&&(c=-1,i+=u-1,o+=u-1);u-- >0;)i in e?e[o]=e[i]:kc(e,o),o+=c,i+=c;return e},Vc=b(Wc),Gc=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("copyWithin",function(t,r){return Vc(Gc(this),t,r,arguments.length>2?arguments[2]:void 0)});var Yc=Qi.every,zc=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("every",function(t){return Yc(zc(this),t,arguments.length>1?arguments[1]:void 0)});var Hc=Ac.aTypedArray,qc=Ac.exportTypedArrayMethod,Xc=b("".slice);qc("fill",function(t){var r=arguments.length;Hc(this);var e="Big"===Xc(Ee(this),0,3)?Lc(t):+t;return s(tu,this,e,r>1?arguments[1]:void 0,r>2?arguments[2]:void 0)},a(function(){var t=0;return new Int8Array(2).fill({valueOf:function(){return t++}}),1!==t}));var Kc=function(t,r){for(var e=0,n=gr(r),o=new t(n);n>e;)o[e]=r[e++];return o},Jc=Ac.aTypedArrayConstructor,$c=Ac.getTypedArrayConstructor,Qc=function(t){return Jc(Yn(t,$c(t)))},Zc=Qi.filter,tf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("filter",function(t){return r=this,e=Zc(tf(this),t,arguments.length>1?arguments[1]:void 0),Kc(Qc(r),e);var r,e});var rf=Qi.find,ef=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("find",function(t){return rf(ef(this),t,arguments.length>1?arguments[1]:void 0)});var nf=Qi.findIndex,of=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("findIndex",function(t){return nf(of(this),t,arguments.length>1?arguments[1]:void 0)});var af=function(t){var r=1===t;return function(e,n,o){for(var i,a=at(e),u=E(a),c=he(n,o),f=gr(u);f-- >0;)if(c(i=u[f],f,a))switch(t){case 0:return i;case 1:return f}return r?-1:void 0}},uf={findLast:af(0),findLastIndex:af(1)},cf=uf.findLast,ff=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("findLast",function(t){return cf(ff(this),t,arguments.length>1?arguments[1]:void 0)});var sf=uf.findLastIndex,pf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("findLastIndex",function(t){return sf(pf(this),t,arguments.length>1?arguments[1]:void 0)});var lf=Qi.forEach,yf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("forEach",function(t){lf(yf(this),t,arguments.length>1?arguments[1]:void 0)});var hf=wr.includes,df=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("includes",function(t){return hf(df(this),t,arguments.length>1?arguments[1]:void 0)});var vf=wr.indexOf,gf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("indexOf",function(t){return vf(gf(this),t,arguments.length>1?arguments[1]:void 0)});var bf=Ac.aTypedArray,wf=Ac.exportTypedArrayMethod,mf=b([].join);wf("join",function(t){return mf(bf(this),t)});var Af=Math.min,Tf=[].lastIndexOf,Of=!!Tf&&1/[1].lastIndexOf(1,-0)<0,Ef=aa("lastIndexOf"),Sf=Of||!Ef?function(t){if(Of)return Xn(Tf,this,arguments)||0;var r=x(this),e=gr(r),n=e-1;for(arguments.length>1&&(n=Af(n,pr(arguments[1]))),n<0&&(n=e+n);n>=0;n--)if(n in r&&r[n]===t)return n||0;return-1}:Tf,jf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("lastIndexOf",function(t){var r=arguments.length;return Xn(Sf,jf(this),r>1?[t,arguments[1]]:[t])});var Rf=Qi.map,xf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("map",function(t){return Rf(xf(this),t,arguments.length>1?arguments[1]:void 0,function(t,r){return new(Qc(t))(r)})});var If=ia.left,Mf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("reduce",function(t){var r=arguments.length;return If(Mf(this),t,r,r>1?arguments[1]:void 0)});var Pf=ia.right,Lf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("reduceRight",function(t){var r=arguments.length;return Pf(Lf(this),t,r,r>1?arguments[1]:void 0)});var Cf=Ac.aTypedArray,Ff=Ac.exportTypedArrayMethod,Uf=Math.floor;Ff("reverse",function(){for(var t,r=this,e=Cf(r).length,n=Uf(e/2),o=0;o<n;)t=r[o],r[o++]=r[--e],r[e]=t;return r});var _f=i.RangeError,Bf=i.Int8Array,Df=Bf&&Bf.prototype,kf=Df&&Df.set,Nf=Ac.aTypedArray,Wf=Ac.exportTypedArrayMethod,Vf=!a(function(){var t=new Uint8ClampedArray(2);return s(kf,t,{length:1,0:3},1),3!==t[1]}),Gf=Vf&&Ac.NATIVE_ARRAY_BUFFER_VIEWS&&a(function(){var t=new Bf(2);return t.set(1),t.set("2",1),0!==t[0]||2!==t[1]});Wf("set",function(t){Nf(this);var r=xc(arguments.length>1?arguments[1]:void 0,1),e=at(t);if(Vf)return s(kf,this,e,r);var n=this.length,o=gr(e),i=0;if(o+r>n)throw new _f("Wrong length");for(;i<o;)this[r+i]=e[i++]},!Vf||Gf);var Yf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("slice",function(t,r){for(var e=Kn(Yf(this),t,r),n=Qc(this),o=0,i=e.length,a=new n(i);i>o;)a[o]=e[o++];return a},a(function(){new Int8Array(1).slice()}));var zf=Qi.some,Hf=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("some",function(t){return zf(Hf(this),t,arguments.length>1?arguments[1]:void 0)});var qf=Math.floor,Xf=function(t,r){var e=t.length,n=qf(e/2);return e<8?Kf(t,r):Jf(t,Xf(ou(t,0,n),r),Xf(ou(t,n),r),r)},Kf=function(t,r){for(var e,n,o=t.length,i=1;i<o;){for(n=i,e=t[i];n&&r(t[n-1],e)>0;)t[n]=t[--n];n!==i++&&(t[n]=e)}return t},Jf=function(t,r,e,n){for(var o=r.length,i=e.length,a=0,u=0;a<o||u<i;)t[a+u]=a<o&&u<i?n(r[a],e[u])<=0?r[a++]:e[u++]:a<o?r[a++]:e[u++];return t},$f=Xf,Qf=B.match(/firefox\/(\d+)/i),Zf=!!Qf&&+Qf[1],ts=/MSIE|Trident/.test(B),rs=B.match(/AppleWebKit\/(\d+)\./),es=!!rs&&+rs[1],ns=Ac.aTypedArray,os=Ac.exportTypedArrayMethod,is=i.Uint16Array,as=is&&le(is.prototype.sort),us=!(!as||a(function(){as(new is(2),null)})&&a(function(){as(new is(2),{})})),cs=!!as&&!a(function(){if(V)return V<74;if(Zf)return Zf<67;if(ts)return!0;if(es)return es<602;var t,r,e=new is(516),n=Array(516);for(t=0;t<516;t++)r=t%4,e[t]=515-t,n[t]=t-2*r+3;for(as(e,function(t,r){return(t/4|0)-(r/4|0)}),t=0;t<516;t++)if(e[t]!==n[t])return!0});os("sort",function(t){return void 0!==t&&$(t),cs?as(this,t):$f(ns(this),function(t){return function(r,e){return void 0!==t?+t(r,e)||0:e!=e?-1:r!=r?1:0===r&&0===e?1/r>0&&1/e<0?1:-1:r>e}}(t))},!cs||us);var fs=Ac.aTypedArray;(0,Ac.exportTypedArrayMethod)("subarray",function(t,r){var e=fs(this),n=e.length,o=hr(t,n);return new(Qc(e))(e.buffer,e.byteOffset+o*e.BYTES_PER_ELEMENT,vr((void 0===r?n:hr(r,n))-o))});var ss=i.Int8Array,ps=Ac.aTypedArray,ls=Ac.exportTypedArrayMethod,ys=[].toLocaleString,hs=!!ss&&a(function(){ys.call(new ss(1))});ls("toLocaleString",function(){return Xn(ys,hs?Kn(ps(this)):ps(this),Kn(arguments))},a(function(){return[1,2].toLocaleString()!==new ss([1,2]).toLocaleString()})||!a(function(){ss.prototype.toLocaleString.call([1,2])}));var ds=Ac.exportTypedArrayMethod,vs=i.Uint8Array,gs=vs&&vs.prototype||{},bs=[].toString,ws=b([].join);a(function(){bs.call({})})&&(bs=function(){return ws(this)});var ms=gs.toString!==bs;ds("toString",bs,ms);var As=Ac.aTypedArray,Ts=Ac.getTypedArrayConstructor;(0,Ac.exportTypedArrayMethod)("toReversed",function(){return function(t,r){for(var e=gr(t),n=new r(e),o=0;o<e;o++)n[o]=t[e-o-1];return n}(As(this),Ts(this))});var Os=Ac.aTypedArray,Es=Ac.getTypedArrayConstructor,Ss=Ac.exportTypedArrayMethod,js=b(Ac.TypedArrayPrototype.sort);Ss("toSorted",function(t){void 0!==t&&$(t);var r=Os(this),e=Kc(Es(r),r);return js(e,t)});var Rs=RangeError,xs=Ac.aTypedArray,Is=Ac.getTypedArrayConstructor,Ms=Ac.exportTypedArrayMethod,Ps=!!function(){try{new Int8Array(1).with(2,{valueOf:function(){throw 8}})}catch(op){return 8===op}}();Ms("with",{with:function(t,r){var e=xs(this),n=pr(t),o=Mc(e)?Lc(r):+r;return function(t,r,e,n){var o=gr(t),i=pr(e),a=i<0?o+i:i;if(a>=o||a<0)throw new Rs("Incorrect index");for(var u=new r(o),c=0;c<o;c++)u[c]=c===a?n:t[c];return u}(e,Is(e),n,o)}}.with,!Ps);var Ls=vt("iterator"),Cs=i.Uint8Array,Fs=b(wn.values),Us=b(wn.keys),_s=b(wn.entries),Bs=Ac.aTypedArray,Ds=Ac.exportTypedArrayMethod,ks=Cs&&Cs.prototype,Ns=!a(function(){ks[Ls].call([1])}),Ws=!!ks&&ks.values&&ks[Ls]===ks.values&&"values"===ks.values.name,Vs=function(){return Fs(Bs(this))};Ds("entries",function(){return _s(Bs(this))},Ns),Ds("keys",function(){return Us(Bs(this))},Ns),Ds("values",Vs,Ns||!Ws,{name:"values"}),Ds(Ls,Vs,Ns||!Ws,{name:"values"}),i.Uint8Array;var Gs=function(){return"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this}(),Ys=Gs.BlobBuilder||Gs.WebKitBlobBuilder||Gs.MSBlobBuilder||Gs.MozBlobBuilder;
/**
	 * @license
	 * Blob.js
	 * A Blob, File, FileReader & URL implementation.
	 * 2018-08-09
	 *
	 * By Eli Grey, http://eligrey.com
	 * By Jimmy Wärting, https://github.com/jimmywarting
	 * License: MIT
	 *   See https://github.com/eligrey/Blob.js/blob/master/LICENSE.md
	 */Gs.URL=Gs.URL||Gs.webkitURL||function(t,r){return(r=document.createElement("a")).href=t,r};var zs=Gs.Blob,Hs=URL.createObjectURL,qs=URL.revokeObjectURL,Xs=Gs.Symbol&&Gs.Symbol.toStringTag,Ks=!1,Js=!1,$s=!!Gs.ArrayBuffer,Qs=Ys&&Ys.prototype.append&&Ys.prototype.getBlob;try{Ks=2===new Blob(["ä"]).size,Js=2===new Blob([new Uint8Array([1,2])]).size}catch(ip){}function Zs(t){return t.map(function(t){if(t.buffer instanceof ArrayBuffer){var r=t.buffer;if(t.byteLength!==r.byteLength){var e=new Uint8Array(t.byteLength);e.set(new Uint8Array(r,t.byteOffset,t.byteLength)),r=e.buffer}return r}return t})}function tp(t,r){r=r||{};var e=new Ys;return Zs(t).forEach(function(t){e.append(t)}),r.type?e.getBlob(r.type):e.getBlob()}function rp(t,r){return new zs(Zs(t),r||{})}if(Gs.Blob&&(tp.prototype=Blob.prototype,rp.prototype=Blob.prototype),Xs)try{File.prototype[Xs]="File",Blob.prototype[Xs]="Blob",FileReader.prototype[Xs]="FileReader"}catch(ip){}function ep(){try{new File([],"")}catch(ip){try{var t=new Function('class File extends Blob {constructor(chunks, name, opts) {opts = opts || {};super(chunks, opts || {});this.name = name;this.lastModifiedDate = opts.lastModified ? new Date(opts.lastModified) : new Date;this.lastModified = +this.lastModifiedDate;}};return new File([], ""), File')();Gs.File=t}catch(ip){t=function(t,r,e){var n=new Blob(t,e),o=e&&void 0!==e.lastModified?new Date(e.lastModified):new Date;return n.name=r,n.lastModifiedDate=o,n.lastModified=+o,n.toString=function(){return"[object File]"},Xs&&(n[Xs]="File"),n},Gs.File=t}}}Ks?(ep(),Gs.Blob=Js?Gs.Blob:rp):Qs?(ep(),Gs.Blob=tp):function(){function t(t){for(var r=[],e=0;e<t.length;e++){var n=t.charCodeAt(e);n<128?r.push(n):n<2048?r.push(192|n>>6,128|63&n):n<55296||n>=57344?r.push(224|n>>12,128|n>>6&63,128|63&n):(e++,n=65536+((1023&n)<<10|1023&t.charCodeAt(e)),r.push(240|n>>18,128|n>>12&63,128|n>>6&63,128|63&n))}return r}function r(t){var r,e,n,o,i,a;for(r="",n=t.length,e=0;e<n;)switch((o=t[e++])>>4){case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:r+=String.fromCharCode(o);break;case 12:case 13:i=t[e++],r+=String.fromCharCode((31&o)<<6|63&i);break;case 14:i=t[e++],a=t[e++],r+=String.fromCharCode((15&o)<<12|(63&i)<<6|63&a)}return r}function e(t){return t&&DataView.prototype.isPrototypeOf(t)}function n(t){for(var r=new Array(t.byteLength),e=new Uint8Array(t),n=r.length;n--;)r[n]=e[n];return r}function o(t){for(var r="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",e=[],n=0;n<t.length;n+=3){var o=t[n],i=n+1<t.length,a=i?t[n+1]:0,u=n+2<t.length,c=u?t[n+2]:0,f=o>>2,s=(3&o)<<4|a>>4,p=(15&a)<<2|c>>6,l=63&c;u||(l=64,i||(p=64)),e.push(r[f],r[s],r[p],r[l])}return e.join("")}var i=Object.create||function(t){function r(){}return r.prototype=t,new r};if($s)var a=["[object Int8Array]","[object Uint8Array]","[object Uint8ClampedArray]","[object Int16Array]","[object Uint16Array]","[object Int32Array]","[object Uint32Array]","[object Float32Array]","[object Float64Array]"],u=ArrayBuffer.isView||function(t){return t&&a.indexOf(Object.prototype.toString.call(t))>-1};function c(r,o){for(var i=0,a=(r=r||[]).length;i<a;i++){var f=r[i];f instanceof c?r[i]=f._buffer:"string"==typeof f?r[i]=t(f):$s&&(ArrayBuffer.prototype.isPrototypeOf(f)||u(f))?r[i]=n(f):$s&&e(f)?r[i]=n(f.buffer):r[i]=t(String(f))}this._buffer=[].concat.apply([],r),this.size=this._buffer.length,this.type=o&&o.type||""}function f(t,r,e){e=e||{};var n=c.call(this,t,e)||this;return n.name=r,n.lastModifiedDate=e.lastModified?new Date(e.lastModified):new Date,n.lastModified=+n.lastModifiedDate,n}if(c.prototype.slice=function(t,r,e){return new c([this._buffer.slice(t||0,r||this._buffer.length)],{type:e})},c.prototype.toString=function(){return"[object Blob]"},f.prototype=i(c.prototype),f.prototype.constructor=f,Object.setPrototypeOf)Object.setPrototypeOf(f,c);else try{f.__proto__=c}catch(ip){}function s(){if(!(this instanceof s))throw new TypeError("Failed to construct 'FileReader': Please use the 'new' operator, this DOM object constructor cannot be called as a function.");var t=document.createDocumentFragment();this.addEventListener=t.addEventListener,this.dispatchEvent=function(r){var e=this["on"+r.type];"function"==typeof e&&e(r),t.dispatchEvent(r)},this.removeEventListener=t.removeEventListener}function p(t,r,e){if(!(r instanceof c))throw new TypeError("Failed to execute '"+e+"' on 'FileReader': parameter 1 is not of type 'Blob'.");t.result="",setTimeout(function(){this.readyState=s.LOADING,t.dispatchEvent(new Event("load")),t.dispatchEvent(new Event("loadend"))})}f.prototype.toString=function(){return"[object File]"},s.EMPTY=0,s.LOADING=1,s.DONE=2,s.prototype.error=null,s.prototype.onabort=null,s.prototype.onerror=null,s.prototype.onload=null,s.prototype.onloadend=null,s.prototype.onloadstart=null,s.prototype.onprogress=null,s.prototype.readAsDataURL=function(t){p(this,t,"readAsDataURL"),this.result="data:"+t.type+";base64,"+o(t._buffer)},s.prototype.readAsText=function(t){p(this,t,"readAsText"),this.result=r(t._buffer)},s.prototype.readAsArrayBuffer=function(t){p(this,t,"readAsText"),this.result=t._buffer.slice()},s.prototype.abort=function(){},URL.createObjectURL=function(t){return t instanceof c?"data:"+t.type+";base64,"+o(t._buffer):Hs.call(URL,t)},URL.revokeObjectURL=function(t){qs&&qs.call(URL,t)};var l=Gs.XMLHttpRequest&&Gs.XMLHttpRequest.prototype.send;l&&(XMLHttpRequest.prototype.send=function(t){t instanceof c?(this.setRequestHeader("Content-Type",t.type),l.call(this,r(t._buffer))):l.call(this,t)}),Gs.FileReader=s,Gs.File=f,Gs.Blob=c}();var np="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";void 0===Gs.btoa&&(Gs.btoa=function(t){var r,e,n,o,i,a=0,u=0,c="",f=[];if(!t)return t;do{r=(i=t.charCodeAt(a++)<<16|t.charCodeAt(a++)<<8|t.charCodeAt(a++))>>18&63,e=i>>12&63,n=i>>6&63,o=63&i,f[u++]=np.charAt(r)+np.charAt(e)+np.charAt(n)+np.charAt(o)}while(a<t.length);c=f.join("");var s=t.length%3;return(s?c.slice(0,s-3):c)+"===".slice(s||3)}),void 0===Gs.atob&&(Gs.atob=function(t){var r,e,n,o,i,a,u=0,c=0,f=[];if(!t)return t;t+="";do{r=(a=np.indexOf(t.charAt(u++))<<18|np.indexOf(t.charAt(u++))<<12|(o=np.indexOf(t.charAt(u++)))<<6|(i=np.indexOf(t.charAt(u++))))>>16&255,e=a>>8&255,n=255&a,f[c++]=64==o?String.fromCharCode(r):64==i?String.fromCharCode(r,e):String.fromCharCode(r,e,n)}while(u<t.length);return f.join("")})},"function"==typeof define&&define.amd?define(t):t();
